mlr_pipeops_fda.bsignal: B-spline Feature Extraction

mlr_pipeops_fda.bsignalR Documentation

B-spline Feature Extraction

Description

This PipeOp extracts features from functional data using B-spline basis functions. The extracted features are B-spline coefficients that represent the functional data in the B-spline basis space. For more details, see FDboost::bsignal(), which is called internally.

Parameters

The parameters are the parameters inherited from PipeOpTaskPreprocSimple, as well as the following parameters:

  • inS :: character(1)
    Type of effect in the covariate index: one of "smooth", "linear", "constant". Default "smooth".

  • knots :: numeric()
    Either the number of interior knots or a vector of their positions.

  • boundary.knots :: numeric(2)
    Boundary points at which to anchor the B-spline basis. Lower and upper boundary points for the spline basis. Defaults to the range of the data.

  • degree :: integer(1)
    The degree of the regression spline. Default is 3L.

  • differences :: integer(1)
    Order of difference penalty. Default is 1L.

  • df :: numeric(1)
    Trace of the hat matrix, controlling smoothness. Default is 4.

  • lambda :: any
    Smoothing parameter of the penalty term.

  • center :: logical(1)
    Reparameterize the unpenalized part to zero-mean? Default is FALSE.

  • cyclic :: logical(1)
    If true the fitted coefficient function coincides at the boundaries.

  • Z :: any
    Custom transformation matrix for the spline design.

  • penalty :: character(1)
    The penalty type: "ps" (P-spline) or "pss" (shrinkage). Default is "ps".

  • check.ident :: logical(1)
    Use checks for identifiability of the effect. Default is FALSE.

Super classes

mlr3pipelines::PipeOp -> mlr3pipelines::PipeOpTaskPreproc -> mlr3pipelines::PipeOpTaskPreprocSimple -> PipeOpFDABsignal

Methods

Public methods

Inherited methods

Method new()

Initializes a new instance of this Class.

Usage
PipeOpFDABsignal$new(id = "fda.bsignal", param_vals = list())
Arguments
id

(character(1))
Identifier of resulting object, default is "fda.bsignal".

param_vals

(named list())
List of hyperparameter settings, overwriting the hyperparameter settings that would otherwise be set during construction. Default list().


Method clone()

The objects of this class are cloneable with this method.

Usage
PipeOpFDABsignal$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

Examples

task = tsk("fuel")
po_bsignal = po("fda.bsignal")
task_bsignal = po_bsignal$train(list(task))[[1L]]
task_bsignal$data()

mlr3fda documentation built on March 31, 2026, 1:06 a.m.