Convert regular functional features (e.g. all individuals are observed at the same time-points) to new columns, one for each input value to the function.
The parameters are the parameters inherited from PipeOpTaskPreprocSimple.
The new names generally append a _1, ..., to the corresponding column name.
However this can lead to name clashes with existing columns.
This is solved as follows:
If a column was called "x" and the feature is "mean", the corresponding new column will
be called "x_mean". In case of duplicates, unique names are obtained using make.unique() and
a warning is given.
mlr3pipelines::PipeOp -> mlr3pipelines::PipeOpTaskPreproc -> mlr3pipelines::PipeOpTaskPreprocSimple -> PipeOpFDAFlatten
new()Initializes a new instance of this Class.
PipeOpFDAFlatten$new(id = "fda.flatten", param_vals = list())id(character(1))
Identifier of resulting object, default "fda.flatten".
param_vals(named list)
List of hyperparameter settings, overwriting the hyperparameter settings that would
otherwise be set during construction. Default list().
clone()The objects of this class are cloneable with this method.
PipeOpFDAFlatten$clone(deep = FALSE)deepWhether to make a deep clone.
task = tsk("fuel")
pop = po("fda.flatten")
task_flat = pop$train(list(task))
Run the code above in your browser using DataLab