mlr_pipeops_fda.fourier: Fast Fourier transform features

mlr_pipeops_fda.fourierR Documentation

Fast Fourier transform features

Description

This PipeOp extracts Fourier coefficients from functional columns. For more details, see stats::fft(), which is called internally. Only the one-sided spectrum is returned since the input is real-valued (Oppenheim and Schafer, 2010).

Parameters

The parameters are the parameters inherited from PipeOpTaskPreprocSimple, as well as the following parameters:

  • type :: character(1)
    Which feature to extract from the Fourier coefficients. "amplitude" returns the magnitude. "phase" returns the phase shift in degrees (values in [-180, 180]). Initial value is "phase".

Super classes

mlr3pipelines::PipeOp -> mlr3pipelines::PipeOpTaskPreproc -> mlr3pipelines::PipeOpTaskPreprocSimple -> PipeOpFDAFourier

Methods

Public methods

Inherited methods

Method new()

Initializes a new instance of this Class.

Usage
PipeOpFDAFourier$new(id = "fda.fourier", param_vals = list())
Arguments
id

(character(1))
Identifier of resulting object, default is "fda.fourier".

param_vals

(named list())
List of hyperparameter settings, overwriting the hyperparameter settings that would otherwise be set during construction. Default list().


Method clone()

The objects of this class are cloneable with this method.

Usage
PipeOpFDAFourier$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

References

Oppenheim, V A, Schafer, W R (2010). Discrete-Time Signal Processing, 3rd edition. Pearson. ISBN 978-0131988422.

Examples

task = tsk("fuel")
po_fourier = po("fda.fourier")
task_fourier = po_fourier$train(list(task))[[1L]]
task_fourier$data()

mlr3fda documentation built on March 31, 2026, 1:06 a.m.