mlr_pipeops_fda.scalerange: Linearly Transform the Domain of Functional Data
Description
Linearly transform the domain of functional data so they are between lower and upper.
The formula for this is \(x' = offset + x * scale\),
where \(scale\) is \((upper - lower) / (max(x) - min(x))\) and
\(offset\) is \(-min(x) * scale + lower\). The same transformation is applied during training and prediction.
Arguments
Parameters
The parameters are the parameters inherited from PipeOpTaskPreproc,
as well as the following parameters:
lower :: numeric(1)
Target value of smallest item of input data. Initialized to 0.
uppper :: numeric(1)
Target value of greatest item of input data. Initialized to 1.
(character(1))
Identifier of resulting object, default "fda.scalerange".
param_vals
(named list())
List of hyperparameter settings, overwriting the hyperparameter settings that would
otherwise be set during construction. Default list().
Method clone()
The objects of this class are cloneable with this method.