| mlr_pipeops_fda.smooth | R Documentation |
Smoothes functional data using tf::tf_smooth().
This preprocessing operator is similar to PipeOpFDAInterpol, however it does not interpolate to unobserved
x-values, but rather smooths the observed values.
The parameters are the parameters inherited from PipeOpTaskPreprocSimple,
as well as the following parameters:
method :: character(1)
One of:
"lowess": locally weighted scatterplot smoothing (default)
"rollmean": rolling mean
"rollmedian": rolling median
"savgol": Savitzky-Golay filtering
All methods but "lowess" ignore non-equidistant arg values.
args :: named list()
List of named arguments that is passed to tf_smooth(). See the help page of tf_smooth() for
default values.
verbose :: logical(1)
Whether to print messages during the transformation.
Is initialized to FALSE.
mlr3pipelines::PipeOp -> mlr3pipelines::PipeOpTaskPreproc -> mlr3pipelines::PipeOpTaskPreprocSimple -> PipeOpFDASmooth
new()Initializes a new instance of this Class.
PipeOpFDASmooth$new(id = "fda.smooth", param_vals = list())
id(character(1))
Identifier of resulting object, default "fda.smooth".
param_vals(named list())
List of hyperparameter settings, overwriting the hyperparameter settings that would
otherwise be set during construction. Default list().
clone()The objects of this class are cloneable with this method.
PipeOpFDASmooth$clone(deep = FALSE)
deepWhether to make a deep clone.
task = tsk("fuel")
po_smooth = po("fda.smooth", method = "rollmean", args = list(k = 5))
task_smooth = po_smooth$train(list(task))[[1L]]
task_smooth
task_smooth$data(cols = c("NIR", "UVVIS"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.