Learn R Programming

mlr3fda (version 0.3.0)

mlr_pipeops_fda.tsfeats: Time Series Feature Extraction

Description

This PipeOp extracts time series features from functional columns.

For more details, see tsfeatures::tsfeatures(), which is called internally.

Arguments

Parameters

The parameters are the parameters inherited from PipeOpTaskPreprocSimple, as well as the following parameters:

  • features :: character()
    Function names which return numeric vectors of features. All features returned by these functions must be named if they return more than one feature. Default is c("frequency", "stl_features", "entropy", "acf_features").

  • scale :: logical(1)
    If TRUE, data is scaled to mean 0 and sd 1 before features are computed. Default is TRUE.

  • trim :: logical(1)
    If TRUE, data is trimmed by trim_amount before features are computed. Values larger than trim_amount in absolute value are set to NA. Default is FALSE.

  • trim_amount :: numeric(1)
    Default level of trimming. Default is 0.1.

  • parallel :: logical(1)
    If TRUE, the features are computed in parallel. Default is FALSE.

  • multiprocess :: any
    The function from the future package to use for parallel processing. Default is future::multisession().

  • na.action :: any
    A function to handle missing values. Default is stats::na.pass().

Naming

The new names generally append a _{feature} to the corresponding column name. If a column was called "x" and the feature is "trend", the corresponding new column will be called "x_trend".

Super classes

mlr3pipelines::PipeOp -> mlr3pipelines::PipeOpTaskPreproc -> mlr3pipelines::PipeOpTaskPreprocSimple -> PipeOpFDATsfeatures

Methods

Inherited methods


Method new()

Initializes a new instance of this Class.

Usage

PipeOpFDATsfeatures$new(id = "fda.tsfeats", param_vals = list())

Arguments

id

(character(1))
Identifier of resulting object, default is "fda.tsfeats".

param_vals

(named list())
List of hyperparameter settings, overwriting the hyperparameter settings that would otherwise be set during construction. Default list().


Method clone()

The objects of this class are cloneable with this method.

Usage

PipeOpFDATsfeatures$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

Run this code
task = tsk("fuel")
po_tsfeats = po("fda.tsfeats")
task_tsfeats = po_tsfeats$train(list(task))[[1L]]
task_tsfeats$data()

Run the code above in your browser using DataLab