Smoothes functional data using tf::tf_smooth().
This preprocessing operator is similar to PipeOpFDAInterpol, however it does not interpolate to unobserved
x-values, but rather smooths the observed values.
Arguments
Parameters
The parameters are the parameters inherited from PipeOpTaskPreprocSimple,
as well as the following parameters:
(character(1))
Identifier of resulting object, default "fda.smooth".
param_vals
(named list())
List of hyperparameter settings, overwriting the hyperparameter settings that would
otherwise be set during construction. Default list().
Method clone()
The objects of this class are cloneable with this method.