| mlr_pipeops_fda.zoom | R Documentation |
Zoom in or out on functional features by restricting their domain to a specified window.
This operation extracts a subset of each function by defining new lower and upper boundaries,
effectively cropping the functional data to focus on a specific region of interest.
Calls tf::tf_zoom() from package tf.
The parameters are the parameters inherited from PipeOpTaskPreprocSimple,
as well as the following parameters:
begin :: numeric()
The lower limit of the domain. Can be a single value applied to all
functional columns, or a numeric of length equal to the number of observations.
The window includes all values where argument >= begin. If not specified,
defaults to the lower limit of each function's domain.
end :: numeric()
The upper limit of the domain.
mlr3pipelines::PipeOp -> mlr3pipelines::PipeOpTaskPreproc -> mlr3pipelines::PipeOpTaskPreprocSimple -> PipeOpFDAZoom
new()Initializes a new instance of this Class.
PipeOpFDAZoom$new(id = "fda.zoom", param_vals = list())
id(character(1))
Identifier of resulting object, default "fda.zoom".
param_vals(named list())
List of hyperparameter settings, overwriting the hyperparameter settings that would
otherwise be set during construction. Default list().
clone()The objects of this class are cloneable with this method.
PipeOpFDAZoom$clone(deep = FALSE)
deepWhether to make a deep clone.
task = tsk("fuel")
pop = po("fda.zoom", begin = 50, end = 100)
task_zoom = pop$train(list(task))[[1L]]
task_zoom$data()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.