mlr_pipeops_fda.zoom: Zoom In/Out on Functional Columns
Description
Zoom in or out on functional features by restricting their domain to a specified window.
This operation extracts a subset of each function by defining new lower and upper boundaries,
effectively cropping the functional data to focus on a specific region of interest.
Calls tf::tf_zoom() from package tf.
Arguments
Parameters
The parameters are the parameters inherited from PipeOpTaskPreprocSimple,
as well as the following parameters:
begin :: numeric()
The lower limit of the domain. Can be a single value applied to all
functional columns, or a numeric of length equal to the number of observations.
The window includes all values where argument >= begin. If not specified,
defaults to the lower limit of each function's domain.
(character(1))
Identifier of resulting object, default "fda.zoom".
param_vals
(named list())
List of hyperparameter settings, overwriting the hyperparameter settings that would
otherwise be set during construction. Default list().
Method clone()
The objects of this class are cloneable with this method.